{% extends "base.html" %}
{% load i18n %}

{% block content %}

{% if validlink %}

<form method="post" action="">
  {{ form.as_p }}

  <input type="submit" value="{% trans 'Submit' %}" />
</form>

{% else %}

<p>{% trans "Password reset failed" %}</p>

{% endif %}

{% endblock %}
