{% extends 'base.html' %}

{% block content %}
    <h1>Delete User?</h1>
    <form action="" method="post">{% csrf_token %}
        <p>Are you sure you want to delete the user {{ object }}?</p>
        <input type="submit" value="Yes, I'm Sure." class="btn btn-danger"/>
    </form>
{% endblock content %}
