{% extends "base.html" %}
{% load i18n %}

{% block content %}
    {% block sidebar %}{% endblock sidebar %}

    <h1>{% trans "Password reset successfully" %}</h1>

    <p>You can now <a href="{% url 'accounts_user_login' %}">{% trans "Log in" %}</a></p>

{% endblock %}
