{% extends 'base.html' %}
{% load crispy_forms_tags %}
{% load staticfiles %}

{% block sidebar %}{% endblock sidebar %}

{% block wrapper %}
    {% block messages %}
        {{ block.super }}
    {% endblock %}

    <div class="col-md-12">
        {% block content %}
            <div class="row">

                <div class="col-md-4">
                    {% crispy form %}
                </div>

                <div class="well col-md-7 col-md-offset-1">
                    <div>
                        <h1>Fabric Bolt</h1>
                        <h3>Fabric Deployments</h3>
                    </div>
                </div>
            </div>

            <style>
                .container{
                    text-align: center;
                }
            </style>
        {% endblock %}
    </div>
{% endblock %}