{% extends 'base.html' %}
{% load render_table from django_tables2 %}
{% load staticfiles sekizai_tags %}

{% block breadcrumb %}
    <ol class="breadcrumb">
        {% block breadcrumb.items %}{% endblock breadcrumb.items %}
    </ol>
{% endblock breadcrumb %}

{% block content %}

    <h1>{% block page_title %}{% endblock page_title %}</h1>
    {% render_table table %}

{% endblock content %}