{% extends 'base.html' %}
{% load render_table from django_tables2 %}

{% block breadcrumb %}
    <ol class="breadcrumb">
        <li class="active">Hosts</li>
    </ol>
{% endblock breadcrumb %}

{% block content %}

    <h1>All Hosts <a href="{% url 'hosts_host_create' %}" class="btn btn-default btn-sm pull-right"><i class="glyphicon glyphicon-plus-sign"></i> Add Host</a></h1>
    {% render_table table %}

{% endblock content %}