{% extends 'base.html' %}
{% load crispy_forms_tags %}
{% load staticfiles %}

{% block sidebar %}{% endblock sidebar %}

{% block wrapper %}
    {% block messages %}
        {{ block.super }}
    {% endblock %}

    <div class="col-md-12">
        {% block content %}
            <h1>Create a Password</h1>

            {% crispy form %}

        {% endblock content %}
    </div>
{% endblock wrapper %}